@@ -3,7 +3,7 @@ struct Application;
 impl Application {
     fn new() -> anyhow::Result<Self> {
         let monitor = wita::monitor_from_point(wita::ScreenPosition::new(0, 0)).unwrap();
-        wita::WindowBuilder::new()
+        wita::Window::builder()
             .inner_size(monitor.size)
             .style(wita::WindowStyle::borderless())
             .build()?;
