@@ -21,7 +21,7 @@ impl wita::EventHandler for Application {
         &mut self,
         _: &wita::Window,
         paths: &[&Path],
-        position: wita::PhysicalPosition<f32>,
+        position: wita::PhysicalPosition<i32>,
     ) {
         println!("drop files: {:?}, {:?}", paths, position);
     }
