@@ -36,8 +36,8 @@ impl wita::EventHandler for Application {
         println!("moved: {:?}", pt);
     }
 
-    fn dpi_changed(&mut self, window: &wita::Window) {
-        println!("dpi changed: {}", window.scale_factor());
+    fn dpi_changed(&mut self, window: &wita::Window, new_dpi: u32) {
+        println!("dpi changed: {} (scale_factor: {})", new_dpi, window.scale_factor());
     }
 
     fn mouse_input(
