@@ -39,6 +39,10 @@ impl wita::EventHandler for Application {
             }
         }
     }
+
+    fn dpi_changed(&mut self, window: &wita::Window, new_dpi: u32) {
+        println!("dpi changed: {} (scale_factor: {})", new_dpi, window.scale_factor());
+    }
 }
 
 fn main() {
