@@ -199,7 +199,7 @@ impl KeyCode {
     }
 }
 
-pub fn as_virtual_key(k: VIRTUAL_KEY) -> VirtualKey {
+pub(crate) fn as_virtual_key(k: VIRTUAL_KEY) -> VirtualKey {
     const ZERO: u16 = b'0' as _;
     const Z: u16 = b'Z' as _;
     const NUMPAD0: u16 = VK_NUMPAD0.0;
@@ -262,7 +262,7 @@ pub fn as_virtual_key(k: VIRTUAL_KEY) -> VirtualKey {
     }
 }
 
-pub fn to_raw_virtual_key(k: VirtualKey) -> VIRTUAL_KEY {
+pub(crate) fn to_raw_virtual_key(k: VirtualKey) -> VIRTUAL_KEY {
     const ZERO: char = '0' as _;
     const Z: char = 'Z' as _;
     match k {
@@ -325,6 +325,8 @@ pub fn to_raw_virtual_key(k: VirtualKey) -> VIRTUAL_KEY {
     }
 }
 
+/// Get the current key state;
+#[inline]
 pub fn get_key_state(k: VirtualKey) -> bool {
     unsafe { GetKeyState(to_raw_virtual_key(k).0 as _) & 0x80 != 0 }
 }
@@ -455,6 +457,7 @@ mod tests {
     }
 }
 
+/// Describes a mouse cursor icon.
 #[derive(Clone, Copy, PartialEq, Eq, Debug)]
 pub enum Cursor {
     AppStarting,
