@@ -105,7 +105,7 @@ pub trait EventHandler {
     fn ime_end_composition(&mut self, window: &Window, result_string: Option<&str>) {}
 
     /// This is called when files have been dropped on the window.
-    fn drop_files(&mut self, window: &Window, paths: &[&Path], position: PhysicalPosition<f32>) {}
+    fn drop_files(&mut self, window: &Window, paths: &[&Path], position: PhysicalPosition<i32>) {}
 
     /// This is called when raw data has been inputed.
     #[cfg(feature = "raw_input")]
