@@ -490,7 +490,7 @@ pub(crate) extern "system" fn window_proc<T: EventHandler + 'static>(
                     eh.drop_files(
                         handle,
                         &files_ref,
-                        PhysicalPosition::new(pt.x as f32, pt.y as f32),
+                        PhysicalPosition::new(pt.x, pt.y),
                     );
                 });
                 DragFinish(hdrop);
