@@ -1,6 +1,4 @@
 //! Provides raw input data.
-//!
-//! To use, specify `"raw_input"` feature.
 
 use crate::context::call_handler;
 use crate::device::*;
@@ -36,14 +34,17 @@ pub enum Value {
 }
 
 impl Value {
+    #[inline]
     pub fn signed(&self) -> bool {
         matches!(self, Self::I8(_) | Self::I16(_) | Self::I32(_))
     }
 
+    #[inline]
     pub fn unsigned(&self) -> bool {
         !self.signed()
     }
 
+    #[inline]
     pub fn bit_size(&self) -> u32 {
         match self {
             Self::I8(_) | Self::U8(_) => 8,
@@ -156,26 +157,31 @@ pub struct Device {
 }
 
 impl Device {
+    #[inline]
     pub fn name(&self) -> Option<&str> {
         self.name.as_deref()
     }
 
+    #[inline]
     pub fn device_type(&self) -> DeviceType {
         self.ty
     }
 
+    #[inline]
     pub fn raw_handle(&self) -> HANDLE {
         self.handle
     }
 }
 
 impl std::fmt::Display for Device {
+    #[inline]
     fn fmt(&self, f: &mut std::fmt::Formatter) -> std::fmt::Result {
         write!(f, "{}", self.name().unwrap_or_default())
     }
 }
 
 impl PartialEq for Device {
+    #[inline]
     fn eq(&self, other: &Self) -> bool {
         self.handle == other.handle
     }
@@ -407,6 +413,7 @@ pub enum WindowState {
 }
 
 impl From<WPARAM> for WindowState {
+    #[inline]
     fn from(src: WPARAM) -> WindowState {
         match src.0 as _ {
             RIM_INPUT => WindowState::Foreground,
@@ -605,6 +612,7 @@ pub struct GamePadData {
 }
 
 impl GamePadData {
+    #[inline]
     pub fn buttons(&self) -> &Vec<bool> {
         self.buttons.as_ref()
     }
